ShadAnchorAuto class

Automatically infers the position of the ShadPortal in the global coordinate system adjusting according to the offset, followerAnchor and targetAnchor properties.

Inheritance
Annotations

Constructors

ShadAnchorAuto({Offset offset = Offset.zero, bool followTargetOnResize = true, AlignmentGeometry followerAnchor = Alignment.bottomCenter, AlignmentGeometry targetAnchor = Alignment.bottomCenter, ShadAnchorAuto? fallback})
const

Properties

fallback ShadAnchorAuto?
The fallback anchor to use when the primary position does not fit within the screen bounds vertically.
final
followerAnchor AlignmentGeometry
The coordinates of the overlay from which the overlay starts, which is calculated from the initial targetAnchor.
final
followTargetOnResize bool
Whether the overlay is automatically adjusted to follow the target widget when the target widget moves dues to a window resize.
final
hashCode int
The hash code for this object.
no setteroverride
offset Offset
The offset of the overlay from the target widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetAnchor AlignmentGeometry
The coordinates of the target from which the overlay starts.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override