followTargetOnResize property

bool followTargetOnResize
final

Whether the overlay is automatically adjusted to follow the target widget when the target widget moves dues to a window resize.

Implementation

final bool followTargetOnResize;