ShadContextMenuItemController class

Inheritance

Constructors

ShadContextMenuItemController({required Key itemKey, bool hovered = false, bool focused = false})

Properties

focused bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hovered bool
no setter
itemKey Key
final
items Map<Key, ShadContextMenuItemController>
Maps the item key to the item controller
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
registerSubItem(ShadContextMenuItemController controller) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setFocused(bool focused) → void
setHovered(bool hovered) → void
toString() String
A string representation of this object.
inherited
unregisterSubItem(ShadContextMenuItemController controller) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited