hideThreshold property
The threshold in pixels for hiding the toolbar when the keyboard is dismissed. Defaults to 20 pixels.
Implementation
final double? hideThreshold;
The threshold in pixels for hiding the toolbar when the keyboard is dismissed. Defaults to 20 pixels.
final double? hideThreshold;