initialValue property

T? get initialValue

The initial value of the field, sourced from widget or parent form.

Implementation

T? get initialValue {
  if (widget.initialValue != null) return widget.initialValue;

  // Use getFieldValue to support nested initial values with dot notation
  if (widget.id == null || _parentForm == null) return null;

  final value = _parentForm!.getFieldValue(widget.id!);
  if (widget.fromValueTransformer != null) {
    return widget.fromValueTransformer!(value);
  }
  return value as T?;
}