ShadFormBuilderTextareaState class

Inheritance

Properties

bucket RestorationBucket?
The RestorationBucket used for the restoration data of the RestorablePropertys registered to this mixin.
no setterinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
controller TextEditingController
no setter
decoration ShadDecoration
The decoration applied to the field, reflecting error state.
no setterinherited
effectiveId String
The effective identifier for the field, using the provided ID or an auto-generated one.
no setterinherited
enabled bool
Whether the field is enabled, factoring in parent form state.
no setterinherited
errorText String?
The current validation error returned by the FormField.validator callback, or the manually provided error message using the FormField.forceErrorText property.
no setterinherited
focusNode FocusNode
The effective focus node, either provided or internally managed.
no setterinherited
forceErrorText String?
no setterinherited
hasError bool
True if this field has any validation errors.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasInteractedByUser bool
Returns true if the user has modified the value of this field.
no setterinherited
initialValue String?
The initial value of the field, sourced from widget or parent form.
no setterinherited
isValid bool
True if the current value is valid.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
restorationId String?
The restoration ID used for the RestorationBucket in which the mixin will store the restoration data of all registered properties.
no setterinherited
restorePending bool
Whether restoreState will be called at the beginning of the next build phase.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textareaKey GlobalKey<State<StatefulWidget>>
final
value String?
The current value of the form field.
no setterinherited
widget ShadTextareaFormField
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
clearError() → void
Clears any visible validation error for this field without resetting the field's value.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChange(String? value) → void
Updates this field's state to the new value. Useful for responding to child widget changes, e.g. Slider's Slider.onChanged argument.
override
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didToggleBucket(RestorationBucket? oldBucket) → void
Called when bucket switches between null and non-null values.
inherited
didUpdateRestorationId() → void
Must be called when the value returned by restorationId changes.
inherited
didUpdateWidget(covariant ShadTextareaFormField oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
ensureVisible() → void
Ensures the field is visible by scrolling if necessary.
inherited
focus() → void
Requests focus for the field's focus node.
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onControllerChanged() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
registerForRestoration(RestorableProperty<Object?> property, String restorationId) → void
Registers a RestorableProperty for state restoration.
inherited
registerFromValueTransformer(Map<String, Function> map) → void
Registers the field’s from value transformer with the provided map.
inherited
registerToValueTransformer(Map<String, Function> map) → void
Registers the field’s value transformer with the provided map.
inherited
reset() → void
Resets the field to its initial value.
override
restoreState(RestorationBucket? oldBucket, bool initialRestore) → void
Called to initialize or restore the RestorablePropertys used by the State object.
inherited
save() → void
Calls the FormField's onSaved method with the current value.
inherited
setError(String? error) → void
Sets an internal error message that overrides validation errors.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setValue(String? value, {bool populateForm = true}) → void
Sets the value associated with this form field.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
unregisterFromRestoration(RestorableProperty<Object?> property) → void
Unregisters a RestorableProperty from state restoration.
inherited
validate() bool
Calls FormField.validator to set the errorText only if FormField.forceErrorText is null. When FormField.forceErrorText is not null, FormField.validator will not be called.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited