ShadKbdTheme class

Theme for the ShadKbd widget.

Annotations

Constructors

ShadKbdTheme({bool canMerge = true, Color? backgroundColor, Color? foregroundColor, ShadBorder? border, EdgeInsetsGeometry? padding, TextStyle? textStyle, double? gap, double? minWidth, double? height})
Theme for the ShadKbd widget.
const

Properties

backgroundColor Color?
The background color of the key cap.
final
border ShadBorder?
The border of the key cap.
final
canMerge bool
no setter
foregroundColor Color?
The text color of the key cap.
final
gap double?
The gap between adjacent keys in a ShadKbd group.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
The height of a single key cap, shadcn's h-5.
final
minWidth double?
The minimum width of a single key cap.
final
padding EdgeInsetsGeometry?
The padding inside the key cap.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
The text style of the key label.
final

Methods

copyWith({Color? backgroundColor, Color? foregroundColor, ShadBorder? border, EdgeInsetsGeometry? padding, TextStyle? textStyle, double? gap, double? minWidth, double? height}) ShadKbdTheme
inherited
merge(ShadKbdTheme? other) ShadKbdTheme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(ShadKbdTheme? a, ShadKbdTheme? b, double t) ShadKbdTheme?