ShadLocalizationsData$pagination$en class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- morePages → String
-
en: 'More pages'
no setter
- next → String
-
en: 'Next'
no setter
- page → String
-
en: 'Page'
no setter
- previous → String
-
en: 'Previous'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited