shadows property
The outer shadows, painted behind decoration and clipped to the region outside its shape.
Implementation
final List<BoxShadow> shadows;
The outer shadows, painted behind decoration and clipped to the region outside its shape.
final List<BoxShadow> shadows;