ShadTextSelectionToolbar class

A simple text-selection toolbar that shows copy/cut/paste buttons styled with ShadTheme. Used as the default ShadInput.contextMenuBuilder.

Inheritance
Available extensions
Annotations
  • @Deprecated('Use ShadContextMenu with ShadContextMenuItem instead. ' 'This widget was deprecated after v0.51.0 and will be removed in v1.0.0.')

Constructors

ShadTextSelectionToolbar({Key? key, required Offset anchor, required List<ContextMenuButtonItem> buttonItems, Color? backgroundColor, BoxBorder? border, BorderRadiusGeometry? borderRadius, List<BoxShadow>? shadows})
const

Properties

anchor Offset
final
backgroundColor Color?
Background color of the toolbar. Defaults to ShadColorScheme.popover.
final
border BoxBorder?
Border of the toolbar. Defaults to a 1-px border using ShadColorScheme.border.
final
borderRadius BorderRadiusGeometry?
Border radius of the toolbar. Defaults to ShadThemeData.radius.
final
buttonItems List<ContextMenuButtonItem>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadows List<BoxShadow>?
Shadows of the toolbar. Defaults to Shadows.md.
final

Methods

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionedWith(ShadPosition position) Widget

Available on Widget, provided by the PositionedExt extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited