ShadToValueTransformer<T> typedef

ShadToValueTransformer<T> = dynamic Function(T value)

A function that transforms the value of a form field into a different format.

Takes a value of type T and returns a transformed value of any type. Used to convert field values before saving or processing

Implementation

typedef ShadToValueTransformer<T> = dynamic Function(T value);