ShadToggleGroup<T> class

A set of ShadToggles sharing a selection.

Mirrors shadcn/ui's ToggleGroup, in single or multiple mode.

ShadToggleGroup<String>(
  values: const {'bold'},
  onChanged: (values) => setState(() => selected = values),
  children: const [
    ShadToggleGroupItem(value: 'bold', child: Icon(LucideIcons.bold)),
    ShadToggleGroupItem(value: 'italic', child: Icon(LucideIcons.italic)),
  ],
)
Inheritance
Available extensions

Constructors

ShadToggleGroup({Key? key, required List<ShadToggleGroupItem<T>> children, Set<T>? values, ValueChanged<Set<T>>? onChanged, ShadToggleGroupController<T>? controller, bool allowDeselection = true, bool enabled = true, ShadToggleVariant toggleVariant = ShadToggleVariant.default_, double? gap, Axis axis = Axis.horizontal, MainAxisSize mainAxisSize = MainAxisSize.min})
A set of ShadToggles sharing a selection.
const
ShadToggleGroup.multiple({Key? key, required List<ShadToggleGroupItem<T>> children, Set<T>? values, ValueChanged<Set<T>>? onChanged, ShadToggleGroupController<T>? controller, bool enabled = true, ShadToggleVariant toggleVariant = ShadToggleVariant.default_, double? gap, Axis axis = Axis.horizontal, MainAxisSize mainAxisSize = MainAxisSize.min})
A group where any number of items may be selected.
const

Properties

allowDeselection bool
Whether tapping the selected item of a single-variant group clears it.
final
axis Axis
The direction the items are laid out in.
final
children List<ShadToggleGroupItem<T>>
The items in the group.
final
controller ShadToggleGroupController<T>?
An external controller for the selection.
final
enabled bool
Whether the whole group responds to input.
final
gap double?
The gap between items.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisSize MainAxisSize
final
onChanged ValueChanged<Set<T>>?
Called with the new selection whenever it changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toggleVariant ShadToggleVariant
The visual style shared by every toggle in the group.
final
values Set<T>?
The selected values. Ignored when controller is provided.
final
variant ShadToggleGroupVariant
final

Methods

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ShadToggleGroup<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionedWith(ShadPosition position) Widget

Available on Widget, provided by the PositionedExt extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited