shad
library
Classes
Adapter
Adapters provide a mechanism to drive an animation from an arbitrary source.
For example, synchronizing an animation with a scroll, controlling
an animation with a slider input, or progressing an animation based on
the time of day.
AlignEffect
An effect that animates the target between the specified begin and end
alignments (via Align ).
Defaults to begin=Align.topCenter, end=Align.center.
Animate
The Flutter Animate library makes adding beautiful animated effects to your widgets
simple. It supports both a declarative and chained API. The latter is exposed
via the Widget.animate extension, which simply wraps the widget in Animate.
AnimateList <T extends Widget >
Applies animated effects to a list of widgets. It does this by wrapping each
widget in Animate , and then proxying calls to all instances. It can
also offset the timing of each widget's animation via interval.
AppLocaleUtils
Provides utility functions without any side effects.
BaseAppLocale <E extends BaseAppLocale <E , T > , T extends BaseTranslations <E , T > >
Similar to flutter locale
but available without any flutter dependencies.
Subclasses will be enums.
BaseAppLocaleUtils <E extends BaseAppLocale <E , T > , T extends BaseTranslations <E , T > >
Provides utility functions without any side effects.
BaseFlutterLocaleSettings <E extends BaseAppLocale <E , T > , T extends BaseTranslations <E , T > >
Similar to BaseLocaleSettings but actually implements
the updateProviderState method.
BaseLocaleSettings <E extends BaseAppLocale <E , T > , T extends BaseTranslations <E , T > >
BaseTranslationProvider <E extends BaseAppLocale <E , T > , T extends BaseTranslations <E , T > >
BaseTranslations <E extends BaseAppLocale <E , T > , T extends BaseTranslations <E , T > >
Root translation class of ONE locale
Entry point for every translation
BlurEffect
An effect that animates a blur on the target between the
specified begin and end blur radiuses (via ImageFiltered ).
Defaults to begin=0, end=4.
BoxShadowEffect
An effect that animates a BoxShadow between begin and end (via DecoratedBox ).
A value of null for either will be interpreted as a shadow that matches the other shadow but
with a zero offset and blurRadius.
You can also specify a borderRadius that defines rounded corners for the shadow.
Defaults to begin=null, end=BoxShadow(color: Color(0x80000000), blurRadius: 8.0, offset: Offset(0.0, 4.0))
CallbackEffect
An effect that calls a callback function at a particular point in the animation.
It includes a boolean value indicating if the animation is playing in reverse.
ChangeNotifierAdapter
Drives an Animate animation from a ChangeNotifier . The valueGetter
should provide a value in the range 0-1 when a change occurs.
ColorEffect
An effect that animates a Color between begin and end, composited with
the target using blendMode (via ColorFiltered ). A color value of null
will be interpreted as a fully transparent version of the other color.
Defaults to begin=null, end=Color(0x800099FF).
CrossfadeEffect
An effect that crossfades the incoming child (including preceeding effects)
with a new widget (via Stack and FadeTransition ). It uses a builder so
that the effect can be reused, but note that the builder is only called once
when the effect initially builds.
CustomEffect
Provide an easy way to add custom animated effects via a builder method that
accepts a BuildContext , target child, and calculated animation value
between begin and end.
DateFormat
DateFormat is for formatting and parsing dates in a locale-sensitive
manner.
EffectEntry
Because Effect classes are immutable and may be reused between multiple
Animate (or AnimateList ) instances, an EffectEntry is created to store
values that may be different between instances. For example, due to an
interval on AnimateList, or from inheriting timing parameters.
EffectList
Simple helper class to build a list of effects via the chained api.
Example:
ElevationEffect
An effect that animates a Material elevation shadow between begin and end (via PhysicalModel ).
You can also specify a shadow color and borderRadius to add rounded corners.
It defaults to begin=0, end=8.
FadeEffect
Animates the opacity of the target between the specified
begin and end values (via FadeTransition ).
It defaults to begin=0, end=1.
FakeAppLocale
FakeTranslations
FlipEffect
An effect that animates a 2.5D card flip rotation effect (via Transform ).
The effect can be horizontal or vertical.
FollowPathEffect
An effect that moves the target following the specified path (via Transform ).
The path coordinates are relative to the target's nominal position.
GlobalShadLocalizations
Flutter localizations delegate for ShadLocalizationsData .
GoogleFontTextStyle
InheritedLocaleData <E extends BaseAppLocale <E , T > , T extends BaseTranslations <E , T > >
ListenEffect
An effect that calls a callback function with its current animation value
between begin and end.
LucideIcons
Lucide Icons
MoveEffect
An effect that moves the target between the specified begin and end
offsets (via Transform.translate ).
Defaults to begin=Offset(0, -16), end=Offset.zero.
transformHitTests is simply passed on to Transform.translate .
NumberFormat
Provides the ability to format a number in a locale-specific way.
PluralResolvers
Default plural resolvers
RichPluralResolvers
Rich plural resolvers
RotateEffect
Effect that rotates the target between begin and end (via RotationTransition ).
Values are specified in "turns" (360° or 2𝝅 radians), so a begin=0.25, end=2.25 would start with the child
rotated a quarter turn clockwise (90 degrees), and rotate two full turns (ending at 810 degrees).
Defaults to begin=-1.0, end=0.
SaturateEffect
An effect that animates the color saturation of the target. The begin and
end values indicate the saturation level, where 0 is fully desaturated
(ie. grayscale) and 1 is normal saturation. Values >1 will oversaturate.
Defaults to begin=0, end=1.
ScaleEffect
An effect that scales the target between the specified begin and end
offset values (via Transform.scale ).
Defaults to begin=Offset(0,0), end=Offset(1,1).
ScrollAdapter
Drives an Animate animation from a ScrollController .
ShadAccentScheme
An accent overlay for a ShadColorScheme .
ShadAccordion <T >
A customizable accordion widget that manages collapsible items.
ShadAccordionController <T >
A controller for managing the state of a ShadAccordion widget.
ShadAccordionItem <T >
An individual item within a ShadAccordion , capable of being expanded or
collapsed.
ShadAccordionState <T >
ShadAccordionTheme
ShadAlert
A customizable alert widget that displays a message with optional icon and
styling.
ShadAlertTheme
ShadAnchor
Manually specifies the position of the ShadPortal in the global
coordinate system.
ShadAnchorAuto
Automatically infers the position of the ShadPortal in the global
coordinate system adjusting according to the offset ,
followerAnchor and targetAnchor properties.
ShadAnchorBase
The position of the ShadPortal in the global coordinate system.
ShadAnimate
The Flutter Animate library makes adding beautiful animated effects to your
widgets simple. It supports both a declarative and chained API. The latter
is exposed via the Widget.animate extension, which simply wraps the widget
in Animate.
ShadAnimatedTheme
Animated version of ShadTheme which automatically transitions the colors
etc, over a given duration whenever the given theme changes.
ShadAnimationBuilder
ShadApp
ShadAppBuilder
The builder for an *App instance.
ShadAvatar
A widget that displays an avatar image with customizable size, shape, and
fallback.
ShadAvatarTheme
ShadBadge
A customizable badge widget that displays content with variant-based
styling.
ShadBadgeTheme
ShadBaseTheme
ShadBlueColorScheme
ShadBorder
A wrapper around the Border class with a reasonable merge.
ShadBorderSide
Creates the side of a border.
ShadBoxBorder
A Border that tolerates differently coloured sides inside a radius.
ShadBreadcrumb
A breadcrumb navigation component that displays the current page location
within a navigational hierarchy.
ShadBreadcrumbDropdown
A dropdown breadcrumb item that displays a menu when clicked.
A single item in a breadcrumb dropdown.
ShadBreadcrumbEllipsis
An ellipsis indicator for breadcrumb navigation.
ShadBreadcrumbLink
A clickable breadcrumb item that navigates when tapped.
ShadBreadcrumbSeparator
A separator widget used between breadcrumb items.
ShadBreadcrumbTheme
ShadBreakpoint
ShadBreakpointLG
ShadBreakpointMD
ShadBreakpoints
ShadBreakpointSM
ShadBreakpointTN
ShadBreakpointXL
ShadBreakpointXXL
ShadButton
A highly customizable button widget with variant and size options.
ShadButtonSizesTheme
The theme for the predefined sizes of ShadButton.
ShadButtonSizeTheme
ShadButtonTheme
The theme for ShadButton.
ShadCalendar
A customizable calendar widget for selecting dates or date ranges.
ShadCalendarModel
Represents the data model for a single month in the calendar.
ShadCalendarTheme
ShadCard
The ShadCard widget provides a container with a title, description, main
content, and optional footer, styled with a background, border, and shadows.
It integrates with ShadTheme for consistent styling and supports leading
and trailing widgets for additional layout flexibility.
ShadCardTheme
ShadCheckbox
A customizable checkbox widget with optional label and sublabel.
ShadCheckboxFormField
ShadCheckboxTheme
ShadCollapsible
An expandable/collapsible section.
ShadCollapsibleController
Controls the open state of a ShadCollapsible .
ShadCollapsibleState
ShadCollapsibleTheme
Theme for the ShadCollapsible widget.
ShadColorScheme
ShadColumn
A Column whose spacing is expressed in steps on the theme's spacing
scale.
ShadCommand
A searchable command palette.
ShadCommandGroup
A titled run of ShadCommandItem s.
ShadCommandItem
A single selectable row in a ShadCommand .
ShadCommandState
ShadCommandTheme
Theme for the ShadCommand widget.
A widget that shows the context menu when the user right clicks the child
or long presses it (only on android and ios), unless a value to
longPressEnabled is provided.
ShadDataTable <T >
A sortable, selectable, paginated table.
ShadDataTableColumn <T >
A column definition for a ShadDataTable .
ShadDataTableController <T >
Holds the sort, filter, paging and selection state of a ShadDataTable .
ShadDatePicker
A customizable date picker widget with a button and popover calendar.
ShadDatePickerFormField
ShadDatePickerTheme
ShadDateRangePickerFormField
ShadDateTimeRange
Encapsulates a start and end DateTime that represent the range of dates.
ShadDecoration
ShadDecorator
ShadDefaultKeyboardToolbar
A default keyboard toolbar with "Previous", "Next", and "Done" buttons.
ShadDefaultKeyboardToolbarTheme
ShadDefaultResizeGrip
A small visual grip used to indicate that the ShadTextarea
is resizable by the user.
ShadDefaultThemeNoSecondaryBorderVariant
ShadDefaultThemeVariant without the outward focus ring.
ShadDefaultThemeVariant
ShadDeterminateProgress
A widget that represents the determinate state of the progress bar.
ShadDialog
A customizable dialog widget for displaying content and actions.
ShadDialogRoute <T >
A custom dialog route that allows specifying a reverseTransitionDuration.
{@macro flutter.widgets.ModalRoute.barrierDismissible}
ShadDialogTheme
ShadDisabled
A widget that disables its child by preventing interaction and applying
visual cues.
ShadEmpty
An empty-state placeholder.
ShadEmptyTheme
Theme for the ShadEmpty widget.
ShaderEffect
Effect that applies an animated fragment shader to a target. See
Writing and using fragment shaders
for information on how to include shaders in your app.
ShaderUpdateDetails
Passed to the ShaderEffect.update callback. Contains information necessary
for updating the shader:
ShadFocusable
ShadForm
A stateful widget that manages a form with validation and field management.
ShadFormBuilderCheckboxState
ShadFormBuilderDatePickerState
ShadFormBuilderDateRangePickerState
ShadFormBuilderField <T >
A customizable form field widget with built-in decoration and state
management.
ShadFormBuilderFieldState <F extends ShadFormBuilderField <T > , T >
The state class for ShadFormBuilderField , managing field state and form
integration.
ShadFormBuilderInputOTPState
ShadFormBuilderInputState
ShadFormBuilderRadioGroupState <T >
ShadFormBuilderSelectMultipleState <T >
ShadFormBuilderSelectState <T >
ShadFormBuilderSwitchState
ShadFormBuilderTextareaState
ShadFormBuilderTimePickerState
ShadFormScope
An inherited widget that provides access to the ShadFormState
ShadFormState
The state class for ShadForm managing form fields and validation
ShadGap
Empty space between two children of a Row , Column or Flex , measured
in steps on the theme's spacing scale.
ShadGestureDetector
A special GestureDetector that handles the hovering state of the child
on devices where the hover is not supported (eg mobile) with the help of
hoverStrategies .
ShadGlobalAnchor
ShadGrayColorScheme
ShadGreenColorScheme
ShadHoverStrategies
ShadIconButton
A customizable icon-only button widget with variant styling.
ShadIndeterminateProgress
A widget that represents the indeterminate state of the progress bar.
ShadIndexProvider
Provides an index to the child widget.
The child widget can access the index using
context.watch<ShadProviderIndex>().index.
ShadInheritedTheme
ShadInput
A customizable text input field with optional leading and trailing widgets.
ShadInputDecorator
ShadInputFormField
ShadInputOTP
A customizable one-time password (OTP) input widget with multiple fields.
ShadInputOTPFormField
ShadInputOTPGroup
ShadInputOTPSlot
ShadInputOTPState
ShadInputOTPTheme
ShadInputState
ShadInputTheme
ShadKbd
A keyboard key cap, used to document a shortcut.
ShadKbdTheme
Theme for the ShadKbd widget.
ShadKeyboardToolbar
Renders a toolbar above the keyboard fully customizable.
ShadLocalizations
Provides access to ShadLocalizationsData from the widget tree.
ShadLocalizationsData
ShadLocalizationsData$command$en
ShadLocalizationsData$datePicker$en
ShadLocalizationsData$empty$en
ShadLocalizationsData$input$en
ShadLocalizationsData$keyboardToolbar$en
ShadLocalizationsData$timePicker$en
ShadLowerCaseTextInputFormatter
ShadMauveColorScheme
The shadcn/ui mauve colour scheme.
A menubar that contains a list of items, typically a list of
ShadMenubarItem .
The controller for managing the selected item of the menubar
A menubar item that contains a list of items, typically a list of
ShadContextMenuItem .
ShadMistColorScheme
The shadcn/ui mist colour scheme.
ShadMouseArea
ShadMouseAreaSurface
A widget that provides notification of a hover inside or outside of a set of
registered regions, grouped by ShadMouseArea.groupId , without
participating in the gesture disambiguation system.
ShadMouseCursorController
ShadMouseCursorProvider
ShadMouseCursorProviderState
ShadNeutralColorScheme
The shadcn/ui neutral colour scheme.
ShadOliveColorScheme
The shadcn/ui olive colour scheme.
ShadOption <T >
ShadOptionTheme
ShadOrangeColorScheme
Shadows
Tailwind's shadow scale.
ShadPadding
Padding measured in steps on the theme's spacing scale.
ShadPaddingEffect
A page navigator.
A compact pagination showing only previous/next and a page counter.
Theme for the ShadPagination widget.
ShadPanelInfo
The size information of a panel
ShadPopover
ShadPopoverController
Controls the visibility of a ShadPopover .
ShadPopoverTheme
ShadPortal
ShadPortalPlacement
Publishes which position the enclosing ShadPortal resolved to: the
primary anchor, or its ShadAnchorAuto.fallback .
ShadPosition
ShadProgress
A customizable linear progress indicator widget.
ShadProgressTheme
ShadProvider <T >
ShadProviderIndex
An immutable class that holds an index .
ShadRadii
A corner-radius scale derived from one base radius.
ShadRadio <T >
A customizable radio button widget that represents a single option in a
radio group.
ShadRadioController <T >
ShadRadioGroup <T >
A customizable radio group widget that allows selection of one item from
a list of options.
ShadRadioGroupFormField <T >
ShadRadioGroupState <T >
ShadRadioTheme
ShadRangeSlider
A slider with more than one thumb, styled to match the Shadcn UI design
system — shadcn/ui's Slider given an array of values.
ShadRangeSliderController
A controller for the ShadRangeSlider widget, managing its values — one
per thumb, in ascending order.
ShadRedColorScheme
ShadResizableController
ShadResizablePanel
A widget that represents a single resizable panel within a
ShadResizablePanelGroup .
ShadResizablePanelGroup
A widget that provides a group of resizable panels, allowing users to
adjust the size of each panel dynamically.
ShadResizablePanelGroupState
ShadResizableTheme
ShadResponsiveBuilder
ShadRestorableTabsController <T >
A restorable version of ShadTabsController for state persistence.
ShadRoseColorScheme
ShadRoundedSuperellipseBorder
A rectangular border with rounded corners following the shape of an
RSuperellipse .
ShadRovingFocus
Wraps a collection of items with arrow-key, Home/End and typeahead
navigation over a ShadRovingFocusController .
ShadRovingFocusController
A controller for a roving-highlight collection such as a tab bar, menu,
toggle group or command palette.
ShadRow
A Row whose spacing is expressed in steps on the theme's spacing scale.
ShadScrollBehavior
Describes how Scrollable widgets behave for ShadApp s.
ShadSelect <T >
A customizable select dropdown widget with various variants and options.
ShadSelectController <T >
Controls the selection state of a ShadSelect widget.
ShadSelectFormField <T >
ShadSelectMultipleFormField <T >
ShadSelectState <T >
ShadSelectTheme
ShadSeparator
A customizable widget that supports horizontal and vertical separators.
ShadSeparatorTheme
Theme for the ShadSeparator widget.
ShadShadowDecoration
A Decoration that paints shadows behind decoration the way CSS paints
an outer box-shadow.
ShadSheet
A customizable sheet component that slides in from the edges of the screen.
ShadSheetController
Controller for an expandable ShadSheet .
ShadSheetGestureDetector
A GestureDetector specifically for ShadSheet to handle drag gestures for
dismissal.
ShadSheetInheritedWidget
Inherited widget to provide ShadSheetSide down the widget tree.
ShadSheetLayoutWithSizeListener
A SingleChildRenderObjectWidget that listens for size changes in its child
and applies layout transformations for ShadSheet animations.
ShadSheetResizeHandle
The gesture target that resizes an expandable ShadSheet when dragged.
ShadSheetTheme
A composable, collapsible side navigation panel.
Controls the open state of a ShadSidebar .
A titled section of sidebar content, shadcn/ui's SidebarGroup +
SidebarGroupLabel + SidebarGroupContent.
A vertical list of menu rows, shadcn/ui's SidebarMenu.
A small hover-accent icon control, shadcn/ui's SidebarMenuAction and
SidebarGroupAction: put it in a menu button's trailing or a group's
action slot.
A count or status marker at the end of a menu row, shadcn/ui's
SidebarMenuBadge.
A row in a sidebar menu, shadcn/ui's SidebarMenuButton.
A placeholder menu row while content loads, shadcn/ui's
SidebarMenuSkeleton.
An indented, bordered list nested under a menu row, shadcn/ui's
SidebarMenuSub. Hidden entirely in the icon rail.
A row inside a ShadSidebarMenuSub , shadcn/ui's SidebarMenuSubButton.
Lays out a ShadSidebar next to the page content, mirroring shadcn/ui's
SidebarProvider + SidebarInset.
What a sidebar descendant needs to know about its host: the controller,
the form factor and the configuration of the ShadSidebar it sits in.
A hairline between sidebar sections, shadcn/ui's SidebarSeparator.
A ghost icon button that toggles the enclosing sidebar, shadcn/ui's
SidebarTrigger.
ShadSizeEffect
ShadSkeleton
A placeholder shown while content is loading.
ShadSkeletonTheme
Theme for the ShadSkeleton widget.
ShadSlateColorScheme
ShadSlider
A customizable slider widget styled to match the Shadcn UI design system.
ShadSliderController
A controller for the ShadSlider widget, managing its value.
ShadSliderTheme
ShadSonner
A widget that manages and displays toasts within the widget tree.
ShadSonnerScope
Allows descendants to access the toaster state via ShadSonner.of or
ShadSonner.maybeOf for showing and hiding toasts.
ShadSonnerState
ShadSonnerTheme
ShadSpacing
A spacing scale, the Dart counterpart of Tailwind's --spacing.
ShadSpinner
An indeterminate circular loading indicator.
ShadSpinnerTheme
Theme for the ShadSpinner widget.
ShadStatesController
ShadStoneColorScheme
The shadcn/ui stone colour scheme.
ShadStyleTokens
The metrics that distinguish one shadcn/ui style from another.
ShadSwitch
A customizable switch widget, styled according to the Shadcn UI design
system.
ShadSwitchFormField
ShadSwitchTheme
ShadTab <T >
Represents a single tab item within a ShadTabs widget.
ShadTable
A customizable table widget for displaying tabular data.
ShadTableCell
A cell widget for use within ShadTable .
ShadTableTheme
ShadTabs <T >
A widget that displays a horizontal series of tabs with associated content.
ShadTabsController <T >
A controller for ShadTabs to manage tab selection.
ShadTabsState <T >
ShadTabsTheme
ShadTaupeColorScheme
The shadcn/ui taupe colour scheme.
ShadTextarea
A customizable multiline textarea widget with
adjustable height and optional resizing grip.
ShadTextareaFormField
ShadTextareaTheme
ShadTextDefaultTheme
ShadTextEditingController
An extension of TextEditingController that stores the previous value.
ShadTextRole
The typographic treatment of one role in a shadcn/ui style.
ShadTextSelectionToolbar
A simple text-selection toolbar that shows copy/cut/paste buttons styled
with ShadTheme . Used as the default ShadInput.contextMenuBuilder .
ShadTextTheme
ShadTheme
ShadThemeData
ShadThemeDataTween
An interpolation between two ShadThemeData s.
ShadThemeScope
Applies a ShadThemeData to a subtree, including the ambient text and icon
styling that comes with it.
ShadThemeVariant
ShadTimeOfDay
Represents a time of day, including hour, minute, and second, and optionally period (AM/PM).
ShadTimePicker
A customizable time picker component with hour, minute, and second inputs.
ShadTimePickerController
A controller for ShadTimePicker to manage the selected time.
ShadTimePickerField
A single input field for ShadTimePicker , used for hour, minute, or second
input.
ShadTimePickerFormField
ShadTimePickerTextEditingController
Custom TextEditingController for ShadTimePickerField to handle time
input formatting and validation.
ShadTimePickerTheme
ShadToast
A customizable toast notification widget.
ShadToaster
A widget that manages and displays toasts within the widget tree.
ShadToasterScope
An inherited widget that provides access to the ShadToasterState .
ShadToasterState
The state class for ShadToaster , managing toast visibility and animations.
ShadToastInfo
ShadToastTheme
ShadToggle
A two-state button that stays pressed when on.
ShadToggleGroup <T >
A set of ShadToggle s sharing a selection.
ShadToggleGroupController <T >
A controller for the selection of a ShadToggleGroup .
ShadToggleGroupItem <T >
A single item within a ShadToggleGroup .
ShadToggleTheme
Theme for the ShadToggle widget.
ShadToolbarButton
A button used inside ShadTextSelectionToolbar .
ShadTooltip
A widget that displays a tooltip on hover or focus, styled to match the
Shadcn UI design system.
ShadTooltipTheme
ShadUpperCaseTextInputFormatter
ShadVioletColorScheme
ShadYellowColorScheme
ShadZincColorScheme
The shadcn/ui zinc colour scheme.
ShakeEffect
Effect that shakes the target, using translation, rotation, or both (via Transform ).
ShimmerEffect
An effect that animates gradient overlay effects (via ShaderMask ), such as the shimmer loading effect
popularized by facebook .
SlideEffect
An effect that moves the target based on a fraction of its size
per the specified begin and end offsets (via SlideTransition ).
Defaults to begin=Offset(0, -0.5), end=Offset.zero
(slide down from half its height).
SpanDecoration
A decoration for a Span.
SpanPadding
Defines the leading and trailing padding values of a Span.
SwapEffect
An effect that swaps out the incoming child for a new child at a particular
point in time. This includes all preceding effects. It uses a builder so
that the effect can be reused, but note that the builder is only called once
when the effect initially builds.
TableVicinity
The relative position of a child in a TableViewport in relation
to other children of the viewport, in terms of rows and columns.
TableViewCell
Creates a cell of the TableView, along with information regarding merged
cells and RepaintBoundary s.
ThenEffect
A special convenience "effect" that makes it easier to sequence effects after
one another. It does this by establishing a new baseline time equal to the
previous effect's end time and its own optional delay.
All subsequent effect delays are relative to this new baseline.
TintEffect
An effect that applies an animated color tint to the target (via ColorFiltered ).
The begin and end values indicate the strength of the tint (0 - 0% tint, 1 - 100% tint).
Defaults to begin=0, end=1.
ToggleEffect
An effect that allows you to toggle the behavior of a builder function at a certain
point in time.
TranslationMetadata <E extends BaseAppLocale <E , T > , T extends BaseTranslations <E , T > >
Metadata instance hold by the root translation class.
TranslationOverridesFlutter
ValueAdapter
Drives an Animate animation directly from a value in the range 0-1
ValueNotifierAdapter
Drives an Animate animation from a ValueNotifier . The value from the
notifier should be in the range 0-1.
VisibilityEffect
An effect that toggles the visibility of the target (via Visibility ).
Defaults to end=true.
Functions
addPasteFilesErrorListener (ShadPasteFilesErrorCallback callback )
→ void
Registers a listener for errors that occur during paste file extraction.
addPasteFilesListener (ShadPasteFilesCallback callback )
→ void
Registers a listener for paste events containing file data.
applyGoogleFontToTextTheme (TextTheme textTheme , {GoogleFontBuilder ? googleFontBuilder })
→ TextTheme
paintOuterShadows (Canvas canvas , Rect rect , {required List <BoxShadow > shadows , required Decoration decoration , TextDirection ? textDirection })
→ void
Paints shadows outside the shape decoration describes for rect, the
way CSS clips an outer box-shadow to the border box.
removePasteFilesErrorListener (ShadPasteFilesErrorCallback callback )
→ void
Removes a previously registered paste files error listener.
removePasteFilesListener (ShadPasteFilesCallback callback )
→ void
Removes a previously registered paste files listener.
shadMaterialThemeFrom (ShadThemeData themeData )
→ ThemeData
Derives the Material ThemeData a ShadThemeData implies.
showShadCommandDialog <T > ({required BuildContext context , required List <ShadCommandGroup > groups , Widget ? placeholder , ShadCommandFilter ? filter , Widget emptyBuilder (BuildContext context , String query )?, bool barrierDismissible = true , double ? width , double ? height })
→ Future <T? >
Shows a ShadCommand as a modal palette, the ⌘K pattern.
showShadDialog <T > ({required BuildContext context , required WidgetBuilder builder , bool barrierDismissible = true , Color ? barrierColor , double ? barrierBlurSigma , String barrierLabel = '' , bool useRootNavigator = true , RouteSettings ? routeSettings , Offset ? anchorPoint , List <Effect > ? animateIn , List <Effect > ? animateOut , ShadDialogVariant variant = ShadDialogVariant.primary , bool opaque = false })
→ Future <T? >
Displays a ShadDialog as a modal dialog with animation.
showShadSheet <T > ({required BuildContext context , required WidgetBuilder builder , ShadSheetSide ? side , Color ? backgroundColor , String barrierLabel = '' , ShapeBorder ? shape , Color ? barrierColor , double ? barrierBlurSigma , bool useRootNavigator = false , bool isDismissible = true , RouteSettings ? routeSettings , Offset ? anchorPoint , List <Effect > ? animateIn , List <Effect > ? animateOut , bool ? opaque = false })
→ Future <T? >
Shows a ShadSheet , which is a modal bottom sheet implementation.
Typedefs
AnimateCallback
= void Function(AnimationController controller )
Function signature for Animate callbacks.
AnimateEffect <T >
= Effect<T >
AnimEffect <T >
= ShadAnimEffect <T >
CustomEffectBuilder
= Widget Function(BuildContext context , double value , Widget child )
FixedTableSpanExtent
= FixedSpanExtent
A span extent with a fixed pixels value.
FocusWidgetBuilder
= ShadFocusWidgetBuilder
FractionalTableSpanExtent
= FractionalSpanExtent
Specified the span extent as a fraction of the viewport extent.
FromValueTransformer <T >
= ShadFromValueTransformer <T >
GoogleFontBuilder
= TextStyle Function({Paint ? background , Color ? backgroundColor , Color ? color , TextDecoration ? decoration , Color ? decorationColor , TextDecorationStyle ? decorationStyle , double ? decorationThickness , List <FontFeature > ? fontFeatures , double ? fontSize , FontStyle ? fontStyle , FontWeight ? fontWeight , Paint ? foreground , double ? height , double ? letterSpacing , Locale ? locale , List <Shadow > ? shadows , TextBaseline ? textBaseline , TextStyle ? textStyle , double ? wordSpacing })
InlineSpanBuilder
= InlineSpan Function(String )
IntlTextDirection
= TextDirection
LowerCaseTextInputFormatter
= ShadLowerCaseTextInputFormatter
MaxTableSpanExtent
= MaxSpanExtent
Returns the larger pixel extent of the two provided TableSpanExtent .
MinTableSpanExtent
= MinSpanExtent
Returns the smaller pixel extent of the two provided TableSpanExtent .
PaddingEffect
= ShadPaddingEffect
PasteFilesCallback
= ShadPasteFilesCallback
PasteFilesErrorCallback
= ShadPasteFilesErrorCallback
PluralResolver
= String Function(num n , {String ? few , String ? many , String ? one , String ? other , String ? two , String ? zero })
Selects the correct string depending on n
RemainingTableSpanExtent
= RemainingSpanExtent
Specifies that the span should occupy the remaining space in the viewport.
ReparentChildBuilder
= Widget Function(Widget parent , Widget child )
The builder type used by Animate.reparentTypes . It must accept an existing
parent widget, and rebuild it with the provided child. In effect, it clones
the provided parent widget with the new child.
ResponsiveWidgetBuilder
= ShadResponsiveWidgetBuilder
RestorableShadTabsController <T >
= ShadRestorableTabsController <T >
ShadAnimEffect <T >
= Effect<T >
ShadClipboardItem
= ({Uint8List bytes , String mimeType } )
A single item read from the system clipboard.
ShadCollapsibleTriggerBuilder
= Widget Function(BuildContext context , bool open , VoidCallback toggle )
Builds the trigger of a ShadCollapsible .
ShadCommandFilter
= List <ShadCommandItem > Function(List <ShadCommandItem > items , String query )
Filters items against the current query.
ShaderUpdateCallback
= EdgeInsets ? Function(ShaderUpdateDetails details )
Function signature for ShaderEffect update handlers.
ShadFocusWidgetBuilder
= Widget Function(BuildContext context , bool focused , Widget ? child )
ShadFormFields
= Map <String , ShadFormBuilderFieldState <ShadFormBuilderField , dynamic > >
A typedef representing a map of form field states with dynamic values.
ShadFromValueTransformer <T >
= T Function(dynamic value )
A function that transforms a value from a different format into the form
field's expected type.
ShadLocalizationsDataEn
= ShadLocalizationsData
ShadPasteFilesCallback
= void Function(List <ShadClipboardItem > files )
Callback for receiving pasted file items.
ShadPasteFilesErrorCallback
= void Function(Object error )
Callback for receiving errors during paste file extraction.
ShadResponsiveWidgetBuilder
= Widget Function(BuildContext context , ShadBreakpoint breakpoint )
ShadSelectedOptionBuilder <T >
= Widget Function(BuildContext context , T value )
Builder for the selected option widget in ShadSelect .
ShadSheetDragEndHandler
= void Function(DragEndDetails details , {required bool isClosing })
A callback for when the user stops dragging the sheet.
ShadSheetDragHandleBuilder
= Widget Function(BuildContext context , ShadSheetSide side )
Builds the drag handle widget for ShadSheet expandable mode.
ShadSheetDragStartHandler
= void Function(DragStartDetails details )
A callback for when the user begins dragging the sheet.
ShadSizeChangeCallback <Size >
= void Function(Size size )
Callback for when the size of a widget changes.
ShadTableCellBuilder
= ShadTableCell Function(BuildContext context , TableVicinity vicinity )
Builder function for creating ShadTableCell widgets.
ShadTooltipController
= ShadPopoverController
Controls the visibility of a ShadTooltip .
ShadToValueTransformer <T >
= dynamic Function(T value )
A function that transforms the value of a form field into a different
format.
SheetDragEndHandler
= ShadSheetDragEndHandler
SheetDragStartHandler
= ShadSheetDragStartHandler
SizeChangeCallback <Size >
= ShadSizeChangeCallback <Size >
SizeEffect
= ShadSizeEffect
TableSpan
= Span
Defines the extent, visual appearance, and gesture handling of a row or
column in a TableView.
TableSpanBuilder
= TableSpan ? Function(int index )
Signature for a function that creates a TableSpan for a given index of row
or column in a TableView.
TableSpanDecoration
= SpanDecoration
A decoration for a TableSpan .
TableSpanExtent
= SpanExtent
Defines the extent of a TableSpan .
ToastInfo
= ShadToastInfo
ToggleEffectBuilder
= Widget Function(BuildContext context , bool value , Widget child )
ToValueTransformer <T >
= ShadToValueTransformer <T >
UpperCaseTextInputFormatter
= ShadUpperCaseTextInputFormatter