ShadDefaultKeyboardToolbarTheme class
Properties
-
backgroundColor
→ Color?
-
The background color of the toolbar, defaults to ShadColorScheme.accent.
final
-
canMerge
→ bool
-
no setter
-
doneText
→ String?
-
The text of the "Done" button, defaults to "Done".
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hideThreshold
→ double?
-
The threshold in pixels for hiding the toolbar when the keyboard is
dismissed. Defaults to 20 pixels.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
showDoneButton
→ bool?
-
Whether to show the "Done" button, defaults to true.
final
-
showNextButton
→ bool?
-
Whether to show the "Next" focus button, defaults to true.
final
-
showPreviousButton
→ bool?
-
Whether to show the "Previous" focus button, defaults to true.
final