ShadInputOTPTheme class
- Annotations
-
- @themeGen
- @immutable
Constructors
- ShadInputOTPTheme({bool canMerge = true, double? gap, TextStyle? style, double? width, double? height, EdgeInsetsGeometry? padding, ShadDecoration? decoration, BorderRadius? firstRadius, BorderRadius? lastRadius, BorderRadius? singleRadius, BorderRadius? middleRadius})
-
const
Properties
- canMerge → bool
-
no setter
- decoration → ShadDecoration?
-
The decoration of the slot
final
- firstRadius → BorderRadius?
-
The radius applied to the first slot of each group
final
- gap → double?
-
The gap between each slot, defaults to 8
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
The height of the slot, defaults to 40
final
- lastRadius → BorderRadius?
-
The radius applied to the last slot of each group
final
- middleRadius → BorderRadius?
-
The radius applied to the middle slots of each group.
If there are 4 slots in a group, the middle slots are the 2nd and 3rd
final
- padding → EdgeInsetsGeometry?
-
The padding of the slot, defaults to EdgeInsets.zero.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleRadius → BorderRadius?
-
The radius applied to the single slot of each group.
Used only if the group has only one slot
final
- style → TextStyle?
-
The style for the input of the slot, defaults to
final
- width → double?
-
The width of the slot, defaults to 40
final
Methods
-
copyWith(
{double? gap, TextStyle? style, double? width, double? height, EdgeInsetsGeometry? padding, ShadDecoration? decoration, BorderRadius? firstRadius, BorderRadius? lastRadius, BorderRadius? singleRadius, BorderRadius? middleRadius}) → ShadInputOTPTheme -
inherited
-
merge(
ShadInputOTPTheme? other) → ShadInputOTPTheme -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
ShadInputOTPTheme? a, ShadInputOTPTheme? b, double t) → ShadInputOTPTheme?