ShadKbd class
A keyboard key cap, used to document a shortcut.
Mirrors shadcn/ui's Kbd. A single key:
const ShadKbd('⌘')
or a chord, rendered as a row of caps:
const ShadKbd.group(['⌘', 'K'])
This is presentational. It documents a shortcut, it does not register one —
use CallbackShortcuts or Shortcuts for that.
- Inheritance
- Available extensions
Constructors
- ShadKbd(String label, {Key? key, Color? backgroundColor, Color? foregroundColor, ShadBorder? border, EdgeInsetsGeometry? padding, TextStyle? textStyle, double? minWidth, double? height})
-
A keyboard key cap, used to document a shortcut.
const
-
ShadKbd.group(List<
String> keys, {Key? key, Color? backgroundColor, Color? foregroundColor, ShadBorder? border, EdgeInsetsGeometry? padding, TextStyle? textStyle, double? gap, double? minWidth, double? height}) -
A group of keys rendered as adjacent caps, e.g.
['⌘', 'K'].const
Properties
- backgroundColor → Color?
-
The background color of the key cap.
final
- border → ShadBorder?
-
The border of the key cap.
final
- foregroundColor → Color?
-
The text color of the key cap.
final
- gap → double?
-
The gap between caps in a group.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
The height of the key cap. Defaults to the theme's.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
keys
→ List<
String> ? -
The labels of a group of key caps.
final
- label → String?
-
The label of a single key cap.
final
- minWidth → double?
-
The minimum width of a single cap, so that
⌘andKline up.final - padding → EdgeInsetsGeometry?
-
The padding inside the key cap.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
The text style of the key label.
final
Methods
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
positionedWith(
ShadPosition position) → Widget -
Available on Widget, provided by the PositionedExt extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited