ShadOrangeColorScheme class
Constructors
-
ShadOrangeColorScheme({required Color background, required Color foreground, required Color card, required Color cardForeground, required Color popover, required Color popoverForeground, required Color primary, required Color primaryForeground, required Color secondary, required Color secondaryForeground, required Color muted, required Color mutedForeground, required Color accent, required Color accentForeground, required Color destructive, required Color destructiveForeground, required Color border, required Color input, required Color ring, required Color selection, Map<String, Color> custom = const {}})
-
const
-
ShadOrangeColorScheme.dark({Color background = const Color(0xff0c0a09), Color foreground = const Color(0xfffafaf9), Color card = const Color(0xff0c0a09), Color cardForeground = const Color(0xfffafaf9), Color popover = const Color(0xff0c0a09), Color popoverForeground = const Color(0xfffafaf9), Color primary = const Color(0xffea580c), Color primaryForeground = const Color(0xfffafaf9), Color secondary = const Color(0xff292524), Color secondaryForeground = const Color(0xfffafaf9), Color muted = const Color(0xff292524), Color mutedForeground = const Color(0xffa8a29e), Color accent = const Color(0xff292524), Color accentForeground = const Color(0xfffafaf9), Color destructive = const Color(0xffef4444), Color destructiveForeground = const Color(0xfffafaf9), Color border = const Color(0xff292524), Color input = const Color(0xff292524), Color ring = const Color(0xffea580c), Color selection = const Color(0xFF355172), Map<String, Color> custom = const {}})
-
const
-
ShadOrangeColorScheme.light({Color background = const Color(0xffffffff), Color foreground = const Color(0xff0c0a09), Color card = const Color(0xffffffff), Color cardForeground = const Color(0xff0c0a09), Color popover = const Color(0xffffffff), Color popoverForeground = const Color(0xff0c0a09), Color primary = const Color(0xfff97316), Color primaryForeground = const Color(0xfffafaf9), Color secondary = const Color(0xfff5f5f4), Color secondaryForeground = const Color(0xff1c1917), Color muted = const Color(0xfff5f5f4), Color mutedForeground = const Color(0xff78716c), Color accent = const Color(0xfff5f5f4), Color accentForeground = const Color(0xff1c1917), Color destructive = const Color(0xffef4444), Color destructiveForeground = const Color(0xfffafaf9), Color border = const Color(0xffe7e5e4), Color input = const Color(0xffe7e5e4), Color ring = const Color(0xfff97316), Color selection = const Color(0xFFB4D7FF), Map<String, Color> custom = const {}})
-
const
Methods
-
applyAccent(Color accent, {Color? accentForeground, bool tintSelection = true})
→ ShadColorScheme
-
Returns a copy of this scheme with
accent applied as the accent hue,
leaving the neutral palette (backgrounds, borders, muted tones) intact.
inherited
-
applyAccentScheme(ShadAccentScheme accent)
→ ShadColorScheme
-
Returns a copy of this scheme with
accent's hue-carrying tokens applied.
inherited
-
copyWith({bool? canMerge, Color? background, Color? foreground, Color? card, Color? cardForeground, Color? popover, Color? popoverForeground, Color? primary, Color? primaryForeground, Color? secondary, Color? secondaryForeground, Color? muted, Color? mutedForeground, Color? accent, Color? accentForeground, Color? destructive, Color? destructiveForeground, Color? border, Color? input, Color? ring, Color? selection, Color? chart1, Color? chart2, Color? chart3, Color? chart4, Color? chart5, Map<String, Color>? custom})
→ ShadColorScheme
-
Creates a copy of this ShadColorScheme but with the given fields
replaced with the new values.
inherited
-
merge(ShadColorScheme? other)
→ ShadColorScheme
-
Merges this ShadColorScheme with
other.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited