ShadPopover class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ShadPopover
- Available extensions
Constructors
-
ShadPopover({Key? key, required Widget child, required WidgetBuilder popover, ShadPopoverController? controller, bool? visible, bool closeOnTapOutside = true, FocusNode? focusNode, ShadAnchorBase? anchor, List<
Effect> ? effects, Duration? reverseDuration, List<BoxShadow> ? shadows, EdgeInsetsGeometry? padding, ShadDecoration? decoration, ImageFilter? filter, Object? groupId, Object? areaGroupId, bool useSameGroupIdForChild = true, TextStyle? textStyle}) -
const
Properties
- anchor → ShadAnchorBase?
-
The position of the popover in the global coordinate system.
final
- areaGroupId → Object?
-
An optional group ID that groups ShadMouseAreas together so that they
operate as one region. If any member of a group is hit by a particular
hover, then all members will have their
onEnteroronExitcalled.final - child → Widget
-
The child widget.
final
- closeOnTapOutside → bool
-
Closes the popover when the user taps outside, defaults to true.
final
- controller → ShadPopoverController?
-
The controller that controls the visibility of the popover.
final
- decoration → ShadDecoration?
-
The decoration of the popover.
final
-
effects
→ List<
Effect> ? -
The animation effects applied to the popover. Defaults to
FadeEffect(), ScaleEffect(begin: Offset(.95, .95), end: Offset(1, 1)), MoveEffect(begin: Offset(0, 2), end: Offset(0, 0)).final - filter → ImageFilter?
-
The filter of the popover. If
null, falls back toShadPopoverTheme.final - focusNode → FocusNode?
-
The focus node of the child, the popover will be shown when
focused.
final
- groupId → Object?
-
The group id of the popover, defaults to
UniqueKey().final - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsetsGeometry?
-
The padding of the popover, defaults to
EdgeInsets.symmetric(horizontal: 12, vertical: 6).final - popover → WidgetBuilder
-
The widget displayed as a popover.
final
- reverseDuration → Duration?
-
The duration of the popover's exit animation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadows
→ List<
BoxShadow> ? -
The shadows applied to the popover, defaults to
Shadows.md.
final
- textStyle → TextStyle?
-
The default text style of the popover's content.
final
- useSameGroupIdForChild → bool
-
Whether the groupId should be used for the child widget, defaults to
true. This teams that taps on the child widget will be handled as inside the popover.final - visible → bool?
-
Indicates if the popover should be visible.
final
Methods
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ShadPopover> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
positionedWith(
ShadPosition position) → Widget -
Available on Widget, provided by the PositionedExt extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited