ShadSheetController class
Controller for an expandable ShadSheet.
Exposes the current size ratio (0..1) and imperative methods animateTo and jumpTo that mirror DraggableScrollableController semantics.
- Inheritance
-
- Object
- ChangeNotifier
- ShadSheetController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
The current size ratio of the sheet (0.0..1.0).
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
double size, {Duration duration = const Duration(milliseconds: 250), Curve curve = Curves.easeInOut}) → Future< void> -
Animates the sheet to
sizeusing the provideddurationandcurve. -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
jumpTo(
double size) → void -
Jumps the sheet to
sizeimmediately, without animation.sizeis clamped to the allowed[0.0, 1.0]range. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited