ShadSonner class
A widget that manages and displays toasts within the widget tree.
The ShadSonner widget acts as a provider for toast notifications, displaying them as overlays on top of its child widget. It uses an InheritedWidget to allow descendants to access its state and show toasts via ShadSonner.of.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ShadSonner
- Available extensions
Constructors
- ShadSonner({Key? key, required Widget child, int? visibleToastsAmount, AlignmentGeometry? alignment, EdgeInsetsGeometry? padding, double? expandedGap, double? collapsedGap, double? scaleFactor, Duration? animationDuration, Curve? animationCurve})
-
Creates a toaster widget that wraps the provided child.
const
Properties
- alignment → AlignmentGeometry?
-
The alignment of the toasts within the widget.
final
- animationCurve → Curve?
-
The curve used for the animation when showing and hiding toasts.
final
- animationDuration → Duration?
-
The duration of the animation when showing and hiding toasts.
final
- child → Widget
-
The widget below the toaster in the tree, over which toasts are displayed.
Typically the main app content.
final
- collapsedGap → double?
-
The gap between toasts in the collapsed state.
final
- expandedGap → double?
-
The gap between toasts in the expanded state.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsetsGeometry?
-
The padding around the toasts.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleFactor → double?
-
The scale factor for the toasts when they are collapsed.
The scale factor is applied to the width and height of the toasts.
The most recent toast will have no scale factor.
The second toast will be scaled to
0.95if thescaleFactoris0.05(1 - 0.05). The third toast will be scaled to0.90if thescaleFactoris0.05(1 - 0.05 * 2).final - visibleToastsAmount → int?
-
The maximum number of toasts that can be displayed at once.
final
Methods
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ShadSonner> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
positionedWith(
ShadPosition position) → Widget -
Available on Widget, provided by the PositionedExt extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf(
BuildContext context) → ShadSonnerState? - Attempts to retrieve the ShadSonnerState from the nearest ShadSonner ancestor.
-
of(
BuildContext context) → ShadSonnerState - Retrieves the ShadSonnerState from the nearest ShadSonner ancestor.