ShadSwitchTheme class
- Annotations
-
- @themeGen
- @immutable
Constructors
- ShadSwitchTheme({bool canMerge = true, Color? thumbColor, Color? uncheckedTrackColor, Color? checkedTrackColor, double? width, double? height, double? margin, Duration? duration, ShadDecoration? decoration, EdgeInsetsGeometry? padding})
-
const
Properties
- canMerge → bool
-
no setter
- checkedTrackColor → Color?
-
Color of the track when the switch is in the checked (on) state.
final
- decoration → ShadDecoration?
-
Custom decoration for the switch track.
final
- duration → Duration?
-
Duration of the animation when toggling the switch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Height of the switch widget.
final
- margin → double?
-
Margin around the thumb within the track.
final
- padding → EdgeInsetsGeometry?
-
Padding between the switch itself and its label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbColor → Color?
-
Color of the switch's thumb (the draggable part).
final
- uncheckedTrackColor → Color?
-
Color of the track when the switch is in the unchecked (off) state.
final
- width → double?
-
Width of the switch widget.
final
Methods
-
copyWith(
{Color? thumbColor, Color? uncheckedTrackColor, Color? checkedTrackColor, double? width, double? height, double? margin, Duration? duration, ShadDecoration? decoration, EdgeInsetsGeometry? padding}) → ShadSwitchTheme -
inherited
-
merge(
ShadSwitchTheme? other) → ShadSwitchTheme -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
ShadSwitchTheme? a, ShadSwitchTheme? b, double t) → ShadSwitchTheme?